#
# spec file for package python-azure-storage-file-share
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if 0%{?suse_version} >= 1500
%define skip_python2 1
%endif
Name:           python-azure-storage-file-share
Version:        12.14.2
Release:        1.1
Summary:        Azure Storage File Share client library for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-storage-file-share/azure-storage-file-share-%{version}.tar.gz
Source1:        LICENSE.txt
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module azure-storage-nspkg >= 3.0.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-core < 2.0.0
Requires:       python-azure-core >= 1.28.0
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-azure-storage-nspkg >= 3.0.0
Requires:       python-cryptography >= 2.1.4
Requires:       python-isodate >= 0.6.1
Requires:       python-typing_extensions >= 4.3.0
Conflicts:      python-azure-sdk <= 2.0.0
BuildArch:      noarch
%python_subpackages

%description
Azure File Share storage offers fully managed file shares in the cloud that are accessible via
the industry standard [Server Message Block (SMB) protocol](https://docs.microsoft.com/windows/
desktop/FileIO/microsoft-smb-protocol-and-cifs-protocol-overview). Azure file shares can be mounted
concurrently by cloud or on-premises deployments of Windows, Linux, and macOS. Additionally,
Azure file shares can be cached on Windows Servers with Azure File Sync for fast access near
where the data is being used.

Azure file shares can be used to:

 * Replace or supplement on-premises file servers
 * "Lift and shift" applications
 * Simplify cloud development with shared application settings,
   diagnostic share, and Dev/Test/Debug tools

%prep
%setup -q -n azure-storage-file-share-%{version}

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-storage-file-share-%{version}
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/storage/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/storage/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/azure/storage/fileshare
%{python_sitelib}/azure_storage_file_share-*.egg-info

%changelog
* Wed Oct 11 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.14.2
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Sep 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.14.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Sep 13 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.14.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove unzip package from BuildRequires
- Switch source archive format to TAR.GZ
* Wed Jul 12 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.13.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Mon Apr 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.12.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Feb 23 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.11.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Oct 19 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.10.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Oct 12 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.10.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Fri Jul  8 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.9.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed May 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.8.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Mar 10 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.7.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename LICENSE.txt to LICENSE in %%files section
- Update Requires from setup.py
* Mon Oct  4 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.6.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Jul  1 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.5.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Mar 24 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.4.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Jan  7 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.4.0b1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Mon Nov 23 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.3.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Aug 26 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.2.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue May  5 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.1.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename HISTORY.md to CHANGELOG.md in %%files section
- Update Requires from setup.py
* Wed Jan 29 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 12.0.0
